@@ -4,7 +4,7 @@
 # Univention S4 Connector
 #  dns helper functions
 #
-# Copyright 2004-2021 Univention GmbH
+# Copyright 2004-2022 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -65,7 +65,7 @@ from samba.provision.sambadns import SOARecord
 from samba.provision.sambadns import SRVRecord
 # def __init__(self, target, port, priority=0, weight=100, serial=1, ttl=900, rank=dnsp.DNS_RANK_ZONE):
 
-from samba.provision.sambadns import CNameRecord
+from samba.provision.sambadns import CNAMERecord
 # def __init__(self, cname, serial=1, ttl=900, rank=dnsp.DNS_RANK_ZONE):
 
 from samba.provision.sambadns import TXTRecord
@@ -614,7 +614,7 @@ def __unpack_txtRecord(object):
 def __pack_cName(object, dnsRecords):
 	for c in object['attributes'].get('cNAMERecord', []):
 		c = __remove_dot(c)
-		c_record = CNameRecord(c)
+		c_record = CNAMERecord(c)
 		dnsRecords.append(ndr_pack(c_record))
 
 
@@ -776,7 +776,7 @@ def s4_zone_msdcs_sync(s4connector, object):
 	soa = soaRecord.split(b' ')
 	serial = int(soa[2])
 
-	# lookup the the SOA record of the _msdcs sub-zone for the domainname zone
+	# lookup the SOA record of the _msdcs sub-zone for the domainname zone
 	msdcs_soa_obj = __get_s4_msdcs_soa(s4connector, domainZoneName)
 	if not msdcs_soa_obj:
 		return
